.. index:: upgrading; from 5.x.x

Upgrading from 3.1.x to 5.x.x
=============================

Note we skipped version 4.x.x because this was a fork of Karaage that never got
completed.

Prerequisites:

* You must be running the latest 3.1.x version to upgrade.
* Downgrading back to earlier versions is not supported and may not work.
* Ensure you only have one machine category before starting.

Clear usage cache before starting. This is optional, but might make the upgrade
faster. It will help if you do have multiple machine categories (but note that
all machine categories will be deleted::

    ./manage.py clear_usage_cache

The ``GLOBAL_DATASTORES`` and ``MACHINE_CATAGEORY_DATASTORES`` should be replaced
with the new ``DATASTORES`` settings.

Confirm everything still works.
